summaryrefslogtreecommitdiffstats
path: root/libkpgp
diff options
context:
space:
mode:
Diffstat (limited to 'libkpgp')
-rw-r--r--libkpgp/kpgpbaseG.cpp2
-rw-r--r--libkpgp/kpgpui.cpp18
2 files changed, 10 insertions, 10 deletions
diff --git a/libkpgp/kpgpbaseG.cpp b/libkpgp/kpgpbaseG.cpp
index a6af3053..251a7737 100644
--- a/libkpgp/kpgpbaseG.cpp
+++ b/libkpgp/kpgpbaseG.cpp
@@ -722,7 +722,7 @@ BaseG::parseKeyData( const TQCString& output, int& offset, Key* key /* = 0 */ )
// check whether uid was utf-8 encoded
bool isUtf8 = true;
for ( unsigned int i = 0; i + 1 < uidString.length(); ++i ) {
- if ( uidString[i].tqunicode() == 0xdbff &&
+ if ( uidString[i].unicode() == 0xdbff &&
uidString[i+1].row() == 0xde ) {
// we found a non-Unicode character (see TQString::fromUtf8())
isUtf8 = false;
diff --git a/libkpgp/kpgpui.cpp b/libkpgp/kpgpui.cpp
index 19323854..37533220 100644
--- a/libkpgp/kpgpui.cpp
+++ b/libkpgp/kpgpui.cpp
@@ -115,7 +115,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
TQVBoxLayout *topLayout = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
group = new TQVGroupBox( i18n("Warning"), this );
- group->tqlayout()->setSpacing( KDialog::spacingHint() );
+ group->layout()->setSpacing( KDialog::spacingHint() );
// (mmutz) work around TQt label bug in 3.0.0 (and possibly later):
// 1. Don't use rich text: No <qt><b>...</b></qt>
label = new TQLabel( i18n("Please check if encryption really "
@@ -132,7 +132,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
- group->tqlayout()->setSpacing( KDialog::spacingHint() );
+ group->layout()->setSpacing( KDialog::spacingHint() );
TQHBox * hbox = new TQHBox( group );
label = new TQLabel( i18n("Select encryption tool to &use:"), hbox );
@@ -153,7 +153,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
topLayout->addWidget( group );
mpOptionsGroupBox = new TQVGroupBox( i18n("Options"), this );
- mpOptionsGroupBox->tqlayout()->setSpacing( KDialog::spacingHint() );
+ mpOptionsGroupBox->layout()->setSpacing( KDialog::spacingHint() );
storePass = new TQCheckBox( i18n("&Keep passphrase in memory"),
mpOptionsGroupBox );
connect( storePass, TQT_SIGNAL( toggled( bool ) ),
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
mEditBox->setReadOnly(true);
topLayout->addWidget( mEditBox, 10 );
- TQString tqunicodeText;
+ TQString unicodeText;
if (charset.isEmpty())
- tqunicodeText = TQString::fromLocal8Bit(text.data());
+ unicodeText = TQString::fromLocal8Bit(text.data());
else {
bool ok=true;
TQTextCodec *codec = KGlobal::charsets()->codecForName(charset, ok);
if(!ok)
- tqunicodeText = TQString::fromLocal8Bit(text.data());
+ unicodeText = TQString::fromLocal8Bit(text.data());
else
- tqunicodeText = codec->toUnicode(text.data(), text.length());
+ unicodeText = codec->toUnicode(text.data(), text.length());
}
- mEditBox->setText(tqunicodeText);
+ mEditBox->setText(unicodeText);
setMinimumSize();
}
void CipherTextDialog::setMinimumSize()
{
// this seems to force a tqlayout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )
(void) mEditBox->paragraphRect( i );
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
void CipherTextDialog::setMinimumSize()
{
- // this seems to force a tqlayout of the entire document, so we get a
+ // this seems to force a layout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )